timeintervaltools.compute_logical_not_of_intervals_in_interval
==============================================================

.. autofunction:: abjad.tools.timeintervaltools.compute_logical_not_of_intervals_in_interval.compute_logical_not_of_intervals_in_interval
